Test data for SampleA, SampleB, SampleC, was generated by using snippy consensus subs file and aligning with nucmer to
generate a list of expected mutations.
See [here](https://github.com/apetkau/thesis-data-simulation/blob/main/jackalope/small/generate-test-assemblies.ipynb)
for more details.

SampleD, SampleE, and SampleF are modified versions of SampleA, SampleB, and SampleC with Ns or gaps (-) inserted in to
test these conditions.
